Authors
=======

.. hint::
   Want to be a part of the project? Read how to `contribute and join us <https://neuropsychology.github.io/NeuroKit/resources/contributing.html>`_!

The full log of contributors is available on `GitHub <https://github.com/neuropsychology/NeuroKit/graphs/contributors>`_.

Current maintainers
-------------------

* `Dominique Makowski <https://github.com/DominiqueMakowski>`_ *(Nanyang Technological University, Singapore)*
* `Danielle Benesch <https://github.com/danibene>`_ *(École de technologie supérieure, Canada)*
* `An Shu Te <https://github.com/anshu-97>`_ *(Nanyang Technological University, Singapore)*
* `Max Ngoi Zi Liang <https://github.com/Max-ZiLiang>`_ *(Nanyang Technological University, Singapore)*


Core contributors
------------------

* `Tam Pham <https://github.com/Tam-Pham>`_ *(Nanyang Technological University, Singapore)*
* `Zen Juen Lau <https://github.com/zen-juen>`_ *(Nanyang Technological University, Singapore)*
* `Jan C. Brammer <https://github.com/JanCBrammer>`_ *(Radboud University, Netherlands)*
* `François Lespinasse <https://github.com/sangfrois>`_ *(Université de Montréal, Canada)*

.. note::
   We might sometimes update the categories, order of display, etc., and we won't necessarily notify each contributor every time. However, if you are for any reasons unsatisfied with the list, or your position in it, please do let us know!


Contributors
-------------

* `Gansheng Tan <https://github.com/GanshengT>`_ *(Washington University, USA)*
* `Hung Pham <https://github.com/hungpham2511>`_ *(Eureka Robotics, Singapore)*
* `Christopher Schölzel <https://github.com/CSchoel>`_ *(THM University of Applied Sciences, Germany)*
* `Duy Le <https://github.com/duylp>`_ *(Hubble, Singapore)*
* `Leonardo Rydin Gorjão <https://github.com/lrydin>`_ *(OsloMet, Norway)*
* `Alexander Wong <https://github.com/awwong1>`_ *(University of Alberta, Canada)*
* `Pierre Elias <https://twitter.com/pierreeliasmd>`_ *(Columbia University, USA)*
* `Jukka Zitting <https://github.com/jukka>`_
* `Stavros Avramidis <https://github.com/purpl3F0x>`_
* `Tiago Rodrigues <https://github.com/TiagoTostas>`_ *(IST, Lisbon)*
* `Mitchell Bishop <https://github.com/Mitchellb16>`_ *(NINDS, USA)*
* `Robert Richer <https://github.com/richrobe>`_ *(FAU Erlangen-Nürnberg, Germany)*
* `Russell Anderson <https://github.com/rpanderson>`_ *(La Trobe Institute for Molecular Science, Australia)*
* `Elaine Teo <https://github.com/elaineteo2000>`_ *(University College London)*
* `Raimon Padrós <https://github.com/raimonpv>`_ *(Universitat politècnica de Catalunya, Spain - Massachusetts General Hospital, USA)*
* `Minsoo Yeo <https://github.com/minsooyeo>`_ *(Taewoong Medical Co., Ltd., ROK)*
* `Celal Savur <https://github.com/csavur>`_ *(Rochester Institute of Technology, USA)*
* `Jacob Epifano <https://github.com/jrepifano>`_ *(Rowan University - Children's Hospital of Philadelphia, USA)*
* `Patryk Wielopolski <https://github.com/pfilo8>`_ *(Wrocław University of Science and Technology, Poland)*
* `Jannik Gut <https://github.com/rostro36>`_
* `Nattapong Thammasan <https://github.com/Nattapong-OnePlanet>`_ *(OnePlanet, Netherlands)*
* `Marek Sokol <https://github.com/sokolmarek>`_ *(Faculty of Biomedical Engineering of the CTU in Prague, Czech Republic)*


Thanks also to `Chuan-Peng Hu <https://github.com/hcp4715>`_, `@ucohen <https://github.com/ucohen>`_, `Anthony Gatti <https://github.com/gattia>`_, `Julien Lamour <https://github.com/lamourj>`_, `@renatosc <https://github.com/renatosc>`_, `Nicolas Beaudoin-Gagnon <https://github.com/Fegalf>`_ and `@rubinovitz <https://github.com/rubinovitz>`_ for their contribution in `NeuroKit 1 <https://github.com/neuropsychology/NeuroKit.py>`_.



.. seealso::

   Information about **how to cite** the software in publications can be found `here <https://neuropsychology.github.io/NeuroKit/cite_us.html>`_.

